@@ -109,7 +109,7 @@ import Control.Monad
 import Control.Monad.Fix
 import qualified Control.Monad.ST as Strict
 import qualified Data.Monoid as Monoid
-import Data.List.NonEmpty
+import Data.List.NonEmpty (NonEmpty(..))
 #if MIN_VERSION_base(4,6,0)
 import Data.Ord (Down(..))
 #else
@@ -172,11 +172,12 @@ import qualified Data.Text.Lazy.Builder as Text
 
 #ifdef MIN_VERSION_hashable
 import Data.Hashable
+import Data.Hashable.Lifted
 #endif
 
 #ifdef MIN_VERSION_unordered_containers
 import Data.HashMap.Lazy as Lazy
-import Data.HashSet
+import Data.HashSet (HashSet)
 #endif
 
 #ifdef LANGUAGE_DeriveDataTypeable
@@ -471,6 +472,10 @@ instance Enum a => Enum (Min a) where
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (Min a) where
   hashWithSalt p (Min a) = hashWithSalt p a
+
+-- | @since 0.19.2
+instance Hashable1 Min where
+  liftHashWithSalt h salt (Min a) = h salt a
 #endif
 
 instance Ord a => Semigroup (Min a) where
@@ -574,6 +579,10 @@ instance Enum a => Enum (Max a) where
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (Max a) where
   hashWithSalt p (Max a) = hashWithSalt p a
+
+-- | @since 0.19.2
+instance Hashable1 Max where
+  liftHashWithSalt h salt (Max a) = h salt a
 #endif
 
 instance Ord a => Semigroup (Max a) where
@@ -761,6 +770,10 @@ instance Enum a => Enum (First a) where
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (First a) where
   hashWithSalt p (First a) = hashWithSalt p a
+
+-- | @since 0.19.2
+instance Hashable1 First where
+  liftHashWithSalt h salt (First a) = h salt a
 #endif
 
 instance Semigroup (First a) where
@@ -848,6 +861,10 @@ instance Enum a => Enum (Last a) where
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (Last a) where
   hashWithSalt p (Last a) = hashWithSalt p a
+
+-- | @since 0.19.2
+instance Hashable1 Last where
+  liftHashWithSalt h salt (Last a) = h salt a
 #endif
 
 instance Semigroup (Last a) where
@@ -973,6 +990,10 @@ newtype WrappedMonoid m = WrapMonoid
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (WrappedMonoid a) where
   hashWithSalt p (WrapMonoid a) = hashWithSalt p a
+
+-- | @since 0.19.2
+instance Hashable1 WrappedMonoid where
+  liftHashWithSalt h salt (WrapMonoid a) = h salt a
 #endif
 
 instance Monoid m => Semigroup (WrappedMonoid m) where
@@ -1062,6 +1083,10 @@ newtype Option a = Option
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (Option a) where
   hashWithSalt p (Option a) = hashWithSalt p a
+
+-- | @since 0.19.2
+instance Hashable1 Option where
+  liftHashWithSalt h salt (Option a) = liftHashWithSalt h salt a
 #endif
 
 instance Functor Option where
